@@ -6,8 +6,9 @@ echo "Warning: This script will run configure for you -- if you need to pass"
 echo "  arguments to configure, please give them as arguments to this script."
 
 aclocal
+automake --add-missing
 autoconf
-automake --foreign --add-missing
+automake --add-missing
 configure $*
 
 exit 0
