@@ -17,6 +17,9 @@
 #include <io.h>
 #endif /* __MSDOS__ */
 
+#ifndef __MSDOS__
+#include <stdlib.h>
+#endif
 #include <stdio.h>
 #include <string.h>
 #include <ctype.h>
